USE master
GO

/******************************************************************************/
--   RESTORE THE BACKUP OF THE PSSA DATABASE     
/******************************************************************************/
PRINT ''
PRINT 'Restoring the backup of the PSSA database'

DECLARE @BackupFile NVARCHAR(2000)
DECLARE @DBname NVARCHAR(1000)

SET @BackupFile = N'C:\PSSA\PSSA.bck'
SET @DBname = N'PSSA'

--Create and restore the database files, if not already present.
IF NOT EXISTS (SELECT [name] FROM master..sysdatabases where name = @DBname)
   BEGIN
	CREATE DATABASE PSSA
	RESTORE DATABASE PSSA  FROM disk=@BackupFile
   END
-- Test and report status.

IF NOT EXISTS(SELECT [name] FROM master..sysdatabases where name = @DBname)
   BEGIN
        PRINT @DBname + N' failed to restore correctly.  Please alter script and try again.'
        PRINT N'Unable to continue script without errors.'
   END
ELSE
   BEGIN
        PRINT @DBname + N' Status RESTORED and ' + CAST(DATABASEPROPERTYEX(@DBname,N'Status') AS NVARCHAR(15) ) 
	PRINT ''
   END

GO


/******************************************************************************/
--   SET UP THE HTM SPATIAL ACCESS FUNCTIONS  
/******************************************************************************/
PRINT ''
PRINT 'Setting up the HTM spatial access functions'


PRINT 'Dropping extended stored procedures, if already exist'

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[xp_HTM_Cover]') and OBJECTPROPERTY(id, N'IsExtendedProc') = 1)
exec sp_dropextendedproc N'[dbo].[xp_HTM_Cover]'
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[xp_HTM_Lookup]') and OBJECTPROPERTY(id, N'IsExtendedProc') = 1)
exec sp_dropextendedproc N'[dbo].[xp_HTM_Lookup]'
GO


PRINT N'Copying DLL to SQL Server BINN directory'
EXEC master..xp_cmdshell 'copy c:\PSSA\sql\xp_SQL_HTM_dll.dll "C:\Program Files\Microsoft SQL Server\MSSQL\Binn" ', no_output
GO


PRINT N'Adding extended procedures.'
SET QUOTED_IDENTIFIER OFF 
SET ANSI_NULLS OFF 
GO

EXEC sp_addextendedproc N'xp_HTM_Cover', N'xp_SQL_HTM_dll.dll'
GRANT EXEC ON xp_HTM_Cover TO PUBLIC
GO
EXEC sp_addextendedproc N'xp_HTM_Lookup', N'xp_SQL_HTM_dll.dll'
GRANT EXEC ON xp_HTM_Lookup TO PUBLIC
GO

SET QUOTED_IDENTIFIER OFF 
SET ANSI_NULLS ON 
GO

PRINT N'HTM code installed in SQL.'




